==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/TURNAROUNDUOM.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDUOMCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "turnarounduomcode",
    "description"
})
@XmlRootElement(name = "TURNAROUNDUOM")
public class TURNAROUNDUOM {

    @XmlElement(name = "TURNAROUNDUOMCODE", required = true)
    protected String turnarounduomcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété turnarounduomcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTURNAROUNDUOMCODE() {
        return turnarounduomcode;
    }

    /**
     * Définit la valeur de la propriété turnarounduomcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTURNAROUNDUOMCODE(String value) {
        this.turnarounduomcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/TURNAROUNDUOM.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDUOMCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "turnarounduomcode",
    "description"
})
@XmlRootElement(name = "TURNAROUNDUOM")
public class TURNAROUNDUOM {

    @XmlElement(name = "TURNAROUNDUOMCODE", required = true)
    protected String turnarounduomcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the turnarounduomcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTURNAROUNDUOMCODE() {
        return turnarounduomcode;
    }

    /**
     * Sets the value of the turnarounduomcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTURNAROUNDUOMCODE(String value) {
        this.turnarounduomcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
